@@ -1,4 +1,3 @@
-import logging
 import os
 import queue
 import threading
@@ -6,8 +5,6 @@ import time
 
 from dusted.config import config
 
-logger = logging.getLogger(__name__)
-
 watcher = None
 stdout = queue.Queue()
 
@@ -23,10 +20,10 @@ class LogfileWatcher:
             try:
                 new_size = os.path.getsize(self.path)
                 if self.file is None or new_size < self.size:
-                    logger.info("Opening new log file")
                     if self.file is not None:
                         self.file.close()
                     self.file = open(self.path, "r")
+                    self.file.seek(max(0, new_size - 4096))
                 self.size = new_size
 
                 while line := self.file.readline():
@@ -42,11 +39,9 @@ class LogfileWatcher:
 def create_proc(uri):
     global watcher
     if watcher is None:
-        logger.info("Starting logfile watcher thread")
         path = os.path.join(config.dustforce_path, "output.log")
         watcher = LogfileWatcher(path)
         logfile_thread = threading.Thread(target=watcher.start, daemon=True)
         logfile_thread.start()
 
-    logger.info(f"Opening uri: {uri}")
     os.startfile(uri)
